package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcSslx;
import org.apache.ibatis.annotations.Param;

/**
 * 涉事类型Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface TcSslxMapper 
{
    /**
     * 查询涉事类型
     * 
     * @param id 涉事类型主键
     * @return 涉事类型
     */
    public TcSslx selectTcSslxById(Long id);

    /**
     * 查询涉事类型列表
     * 
     * @param tcSslx 涉事类型
     * @return 涉事类型集合
     */
    public List<TcSslx> selectTcSslxList(TcSslx tcSslx);

    /**
     * 新增涉事类型
     * 
     * @param tcSslx 涉事类型
     * @return 结果
     */
    public int insertTcSslx(TcSslx tcSslx);

    /**
     * 修改涉事类型
     * 
     * @param tcSslx 涉事类型
     * @return 结果
     */
    public int updateTcSslx(TcSslx tcSslx);

    /**
     * 删除涉事类型
     * 
     * @param id 涉事类型主键
     * @return 结果
     */
    public int deleteTcSslxById(Long id);

    /**
     * 批量删除涉事类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcSslxByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
